﻿<?xml version="1.0" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt" exclude-result-prefixes="msxsl">
	<xsl:output method="html" omit-xml-declaration="yes"/>
	<xsl:template match="/">

		<div class="pageHeader">Report date:&#160;&#160;<xsl:value-of select="msxsl:format-date(Transactions/@ReportDateTime, 'M/d/yyyy')"/>&#160;&#160;<xsl:value-of select="msxsl:format-time(Transactions/@ReportDateTime, 'h:mm tt')"/></div>

		<xsl:if test="Transactions/@IncludeTime = 'yes'">
			<table class="Table">
				<caption class="Caption">Time Transactions for <xsl:value-of select="Transactions/UserName" /></caption>
				<thead>
					<tr>
						<td class="Trx_th col1">Project</td>
						<td class="Trx_th col2">Task</td>
						<td class="Trx_th col3">Date</td>
						<td class="Trx_th col4">Cost Cat.</td>
						<td class="Trx_th col5">Sub-Cost Cat.</td>
						<td class="Trx_th_r col6">Hours</td>
					</tr>
				</thead>
				<xsl:for-each select="Transactions/Time/Transaction">
					<xsl:sort select="TransactionDate" />
					<xsl:sort select="ProjectID" />
					<xsl:sort select="TaskID" />
					<tr>
						<td class="Trx_td col1"><xsl:value-of select="ProjectID" /></td>
						<td class="Trx_td col2"><xsl:value-of select="TaskID" /></td>
						<td class="Trx_td col3"><xsl:value-of select="msxsl:format-date(TransactionDate, 'MM/dd/yyyy')" /></td>
						<td class="Trx_td col4"><xsl:value-of select="CostCategoryString" /></td>
						<td class="Trx_td col5"><xsl:value-of select="SubCostCategoryString" /></td>
						<td class="Trx_td_r col6"><xsl:value-of select="format-number(CostQuantity,'#.00')" /></td>
					</tr>
					<xsl:if test="TransactionDescription != '' and not(starts-with(normalize-space(BillingDescription), normalize-space(TransactionDescription)))">
						<tr>
							<td class="DescLine" colspan="6"><xsl:value-of select="TransactionDescription" /></td>
						</tr>
					</xsl:if>
					<xsl:if test="BillingDescription != ''">
						<tr>
							<td class="DescLine" colspan="6"><xsl:value-of select="BillingDescription" /></td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf_r">Total</td>
					<td class="Trx_tf_r"><xsl:value-of select="format-number(sum(Transactions/Time/Transaction/CostQuantity),'#.00')" /></td>
				</tr>
			</table>

			<p></p>
		</xsl:if>


		<xsl:if test="Transactions/@IncludeExpense = 'yes'">
			<table class="Table">
				<caption class="Caption">Expense Transactions for <xsl:value-of select="Transactions/UserName" /></caption>
				<thead>
					<tr>
						<td class="Trx_th col1">Project</td>
						<td class="Trx_th col2">Task</td>
						<td class="Trx_th col3">Date</td>
						<td class="Trx_th col4">Cost Cat.</td>
						<td class="Trx_th col5">Sub-Cost Cat.</td>
						<td class="Trx_th_r col6">Qty</td>
						<td class="Trx_th_r col6">Ext Amt</td>
						<td class="Trx_th_r col6">Orig ID</td>
						<td class="Trx_th_r col6">Orig Amt</td>
					</tr>
				</thead>
				<xsl:for-each select="Transactions/Expense/Transaction">
					<xsl:sort select="TransactionDate" />
					<xsl:sort select="ProjectID" />
					<xsl:sort select="TaskID" />
					<tr>
						<td class="Trx_td"><xsl:value-of select="ProjectID" /></td>
						<td class="Trx_td"><xsl:value-of select="TaskID" /></td>
						<td class="Trx_td"><xsl:value-of select="msxsl:format-date(TransactionDate, 'MM/dd/yyyy')" /></td>
						<td class="Trx_td"><xsl:value-of select="CostCategoryString" /></td>
						<td class="Trx_td"><xsl:value-of select="SubCostCategoryString" /></td>
						<td class="Trx_td_r"><xsl:value-of select="format-number(CostQuantity,'#.00')" /></td>
						<td class="Trx_td_r"><xsl:value-of select="format-number(CostExtendedAmount,'$#.00')" /></td>
						<td class="Trx_td_r"><xsl:value-of select="CurrencyID" /></td>
						<td class="Trx_td_r"><xsl:value-of select="format-number(OriginatingCostExtendedAmount,'#.00')" /></td>
					</tr>
					<xsl:if test="TransactionDescription != '' and not(starts-with(normalize-space(BillingDescription), normalize-space(TransactionDescription)))">
						<tr>
							<td class="DescLine" colspan="6">
								<xsl:value-of select="TransactionDescription" />
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="BillingDescription != ''">
						<tr>
							<td class="DescLine" colspan="6">
								<xsl:value-of select="BillingDescription" />
							</td>
						</tr>
					</xsl:if>
				</xsl:for-each>
				<tr>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf_r">Total</td>
					<td class="Trx_tf_r"><xsl:value-of select="format-number(sum(Transactions/Expense/Transaction/CostExtendedAmount),'$#.00')" /></td>
					<td class="Trx_tf"></td>
					<td class="Trx_tf_r"><xsl:value-of select="format-number(sum(Transactions/Expense/Transaction/OriginatingCostExtendedAmount),'#.00')" /></td>
				</tr>
			</table>
		</xsl:if>

	</xsl:template>
</xsl:stylesheet>
